/**
 * CTextArea
 * @author Tevin
 */

<template>
    <view class="c-textarea">
        <AtInput
            ref="input"
            :name="itemRes.name"
            :title="itemRes.label"
            :required="itemRes.required"
            :disabled="itemRes.disabled"
            :error="itemRes.error"
        />
        <textarea
            ref="textarea"
            class="textarea"
            :style="{minHeight: areaHeight}"
            :placeholder="placeholder"
            :value="itemRes.formData[itemRes.name]"
            :autoFocus="false"
            :autoHeight="true"
            @input="evt=>itemRes.onChange(evt.detail.value)"
        />
    </view>
</template>

<script>
import Taro from '@tarojs/taro';
import { $ } from '@tarojs/extend';
import { AtInput } from 'taro-ui-vue';
import './cTextArea.scss';

export default {
    name: 'CTextArea',
    components: {
        AtInput,
    },
    props: {
        // 表单数据资源（表单组件内部机制专用）
        itemRes: Object,
        // 文本域输入区域高度
        height: Number,
        // 文本雨输入区行数
        rows: Number,
        // 占位提示
        placeholder: String,
    },
    data() {
        return {};
    },
    computed: {
        areaHeight() {
            if (this.rows) {
                return Taro.pxTransform(this.rows * 40, 750);
            } else {
                return Taro.pxTransform(this.height, 750);
            }
        },
    },
    methods: {},
    mounted() {
        if (process.env.TARO_ENV === 'h5') {
            $(this.$refs.input.$el)
                .find('.at-input__input')
                .prepend(this.$refs.textarea.$el);
        } else if (process.env.TARO_ENV === 'weapp') {
            $(this.$refs.input.$el)
                .find('.at-input__container')
                .append(this.$refs.textarea);
        }
    },
};
</script>